flutter_future_progress_dialog library

Classes

Failure<T>
A failed result containing the error and optional stackTrace.
ProgressDialogResult<T>
The result of an asynchronous operation shown in a progress dialog.
Success<T>
A successful result containing the value returned by the task.

Functions

showAdaptiveProgressDialog<T>({required BuildContext context, required Task<T> future, WidgetBuilder? builder, bool useRootNavigator = true, Offset? anchorPoint, String? barrierLabel, TraversalEdgeBehavior? traversalEdgeBehavior, Color? barrierColor, bool useSafeArea = true, bool? requestFocus}) Future<ProgressDialogResult<T>>
Shows a platform-adaptive progress dialog while executing an asynchronous task.
showCupertinoProgressDialog<T>({required BuildContext context, required Task<T> future, WidgetBuilder? builder, Offset? anchorPoint, String? barrierLabel, bool useRootNavigator = true, Color? barrierColor, bool? requestFocus}) Future<ProgressDialogResult<T>>
Shows a Cupertino-styled progress dialog while executing an asynchronous task.
showProgressDialog<T>({required BuildContext context, required Task<T> future, WidgetBuilder? builder, bool useRootNavigator = true, Offset? anchorPoint, String? barrierLabel, bool? requestFocus, TraversalEdgeBehavior? traversalEdgeBehavior, Color? barrierColor, bool useSafeArea = true, bool fullscreenDialog = false, AnimationStyle? animationStyle}) Future<ProgressDialogResult<T>>
Shows a progress dialog while executing an asynchronous task.

Typedefs

Task<T> = Future<T> Function()